@@ -88,7 +88,9 @@ class Embed():
     def __init__(self):
         self.embed = {}
         self.fields = []
-        
+    
+    def __repr__(self):
+        return repr(self.embed)
 
     def description(self, description):
         """Set embed description"""
